{% extends "django_pam/base.html" %}
{% load staticfiles %}
{% block script %}
    <link rel="stylesheet" href="{% static 'django_pam/css/auth.css' %}">
{% endblock %}
{% block content %}{% include "django_pam/accounts/_logout.html" %}{% endblock %}
