      <div id="dp-login" class="modal fade" role="dialog">
        <div class="modal-dialog modal-sm">
          <div class="modal-content">
            <div class="modal-header">
              <!-- button type="button" class="close" data-dismiss="modal">
                &times;</button -->
              <h4 class="modal-title">Login</h4>
              <div class="all-error" hidden>
                <span>Error:</span>
              </div>
            </div>
            <div class="modal-body">
              <form name="login" role="form" method="post" action="">
                <input name="next" type="hidden" value="{{ next }}" />
                <div class="form-fields">
                  <label for="username">Username</label>
                  <input type="text" name="username" />
                </div>
                <div class="form-fields">
                  <label for="password">Password</label>
                  <input type="password" name="password" />
                </div>
              </form>
            </div>
            <div class="modal-footer">
              <button type="button" name="login-submit"
                      class="btn btn-default">Login</button>
            </div>
          </div>
        </div>
      </div>
