* {
  margin: 0;
  padding: 0;
  box-sizing: border-box;
}

body {
  font-family: Arial, Helvetica, sans-serif;
  margin: 0;
  padding: 0;
  padding-bottom: 3em;
  background-color: rgba(245, 240, 240, 1);
  font-size: medium;
  color: rgba(146, 113, 28, 1);
}

div.content {
  width: 100%;
  margin: 10px 0;
}

div.login,
div.logout {
  width: 300px;
  margin: 0 auto;
}

div.login h2,
div.logout h2 {
  margin: 5px 0;
  text-align: center;
}

div.alert-error {
  margin-bottom: 10px;
  background-color: rgba(245, 208, 208, 0.5);
  color: rgba(120, 105, 30, 1);
  border-style: solid;
  border-color: rgba(250, 190, 190, 1);
  border-width: 1px;
}

div.alert-error ul.errorlist {
  margin: 0;
  font-size: 80%;
}

div.alert-error span {
  margin-left: 4px;
  font-weight: bold;
}

div.alert-error ul {
  padding-left: 30px;
}

div.alert-error button.close-message {
  float: right;
  background-color: initial;
  border: none;
  padding: 0 4px;
}

div.form-fields ul.errorlist {
  margin: 4px 22px;
  font-size: 80%;
  background-color: rgba(245, 208, 208, 0.5);
  color: rgba(120, 105, 30, 1);
}

div.form-fields,
div.login-body button[type=submit] {
  margin: 10px auto 5px auto;
  width: 80%;
}

div.login-body button[type=submit],
div.logout-body button[type=submit] {
  display: block;
  width: 70%;
  margin: 10px auto;
  background-color: rgba(190, 170, 110, 1);
  color: white;
}

div.login-body label {
  display: block;
  width: 80px;
  float: left;
}

div.login-body input {
  display: block;
}
