* {
  margin: 0;
  padding: 0;
  box-sizing: border-box;
}

div#dp-logout div.modal-header,
div#dp-logout div.modal-footer {
  border: none;
}

div.modal-header div.all-error {
  margin: 4px 0 -10px 0;
  background-color: rgba(245, 208, 208, 0.5);
  color: rgba(50, 50, 70, 1);
  border-style: solid;
  border-color: rgba(250, 190, 190, 1);
  border-width: 1px;
}

div.modal-header ul.errorlist {
  margin: 0 22px;
  font-size: 80%;
}

div.modal-header div.all-error span {
  margin-left: 4px;
}

div#dp-logout div.modal-body {
  padding: 0;
}

div.modal-body ul.errorlist {
  margin: 0 22px;
  font-size: 80%;
  background-color: rgba(245, 208, 208, 0.5);
  color: rgba(50, 50, 70, 1);
}

div.modal-body div.form-fields {
  width: 100%;
}

div.modal-body div.form-fields label {
  display: inline-block;
  width: 30%;
  margin: 5px;
  font-weight: 700;
}

div.modal-body div.form-fields input[type=text],
div.modal-body div.form-fields input[type=password] {
  width: 60%;
}

div.modal-footer button {
  width: 100%;
  font-size: 125%;
}
